# UESScriptContext object is used for access script parameters and other environment settings (some
# settings are used only for server-side scripting, using them on client has no effect at all).
#
# <tt><b>author</b></tt> uni430
#
# <tt><b>since</b></tt> UES7-02
class Ues::Platform::Script::UESScriptContext

  # Reads parameters of running script. In case parameter with
  # given name does not exist, nil is returned.
  #
  # <tt><b>param</b></tt> name Name of parameter (must be String)
  #
  # <tt><b>return</b></tt> Value of parameter or nil if parameter does not exist
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.getParameter(name)
    value = nil
    if (name != nil)
      if ($UES_SCRIPT_PARAMS != nil)
        value = $UES_SCRIPT_PARAMS[name]
      end
      if (value == nil)
        value = eval("$" + name)
      end
    end
    if (value.java_kind_of?Java::java.util.Date)
      value = Time.at(value.getTime/1000)
    end
    return value
  end
  class << Ues::Platform::Script::UESScriptContext
    alias parameter getParameter
  end

  # Reads options of running script. In case option with
  # given name does not exist, nil is returned.
  #
  # <tt><b>param</b></tt> name Name of option (must be String)
  #
  # <tt><b>return</b></tt> Value of option or nil if option does not exist
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-12
  def self.getOption(name)
    if ((name != nil) && ($UES_SCRIPT_OPTIONS != nil))
      return $UES_SCRIPT_OPTIONS[name]
    else
      return nil
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias option getOption
  end

  # Returns actual refire count.
  #
  # <tt><b>return</b></tt>
  # * -1 - Information not available
  # *  0 - First run of script
  # *  N - Refire count
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.getRefireCount
    if (Java::cz.ues.platform.essentials.reflection.ClassHelper.getClass("cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext") != nil)
      return Java::cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext.getInstance().getRefireCount()
    else
      return -1
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias refire_count getRefireCount
  end

  # Sets maximum refire count of script in case of failure.
  #
  # <tt><b>param</b></tt> maxRefireCount
  # * -1 - Use default value from container.
  # *  0 - Disable script refire
  # *  N - Maximum refire count
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.setMaxRefireCount(cnt)
    if (Java::cz.ues.platform.essentials.reflection.ClassHelper.getClass("cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext") != nil)
      Java::cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext.getInstance().setMaxRefireCount(cnt)
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias max_refire_count= setMaxRefireCount
  end

  # Returns maximum refire count of script in case of failure.
  #
  # <tt><b>return</b></tt>
  # * -1 - Use default value from container.
  # *  0 - Disable script refire
  # *  N - Maximum refire count
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.getMaxRefireCount
    if (Java::cz.ues.platform.essentials.reflection.ClassHelper.getClass("cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext") != nil)
      return Java::cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext.getInstance().getMaxRefireCount()
    else
      return -1
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias max_refire_count getMaxRefireCount
  end

  # Sets flag for enabling of script recovery.
  #
  # <tt><b>param</b></tt> recoveryEnabled true/false
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.setRecoveryEnabled(recoveryEnabled)
    if (Java::cz.ues.platform.essentials.reflection.ClassHelper.getClass("cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext") != nil)
      Java::cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext.getInstance().setRecoveryEnabled(recoveryEnabled)
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias recovery_enabled= setRecoveryEnabled
  end

  # Reads flag for enabling of script recovery.
  #
  # <tt><b>return</b></tt> true/false
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES7-02
  def self.isRecoveryEnabled
    if (Java::cz.ues.platform.essentials.reflection.ClassHelper.getClass("cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext") != nil)
      return Java::cz.unicorn.afu_v1.af_v1.appc_v1.jobm_v2.JOBMContext.getInstance().isRecoveryEnabled()
    else
      return true
    end
  end
  class << Ues::Platform::Script::UESScriptContext
    alias recovery_enabled? isRecoveryEnabled
  end
  
  # Returns script artifact URI.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES7-10 FP5
  def self.getScriptUri
    return self.getOption("scriptUri")
  end
  class << Ues::Platform::Script::UESScriptContext
    alias scriptUri getScriptUri
  end
  
  # Returns immutable hash with parameters of running script.
  #
  # <tt><b>return</b></tt> Immutable hash with parameters of running script
  #
  # <tt><b>since</b></tt> UES8-05 HF2
  def self.getParameters
    $UES_SCRIPT_PARAMS.clone.freeze unless $UES_SCRIPT_PARAMS.nil?
  end
  class << Ues::Platform::Script::UESScriptContext
    alias parameters getParameters
  end

end
